<?php

/**
 * Acclaro translator UI.
 */
class TMGMTAcclaroTranslatorUIController extends TMGMTDefaultTranslatorUIController {

  /**
   * {@inheritdoc}
   */
  public function pluginSettingsForm($form, &$form_state, TMGMTTranslator $translator, $busy = FALSE) {
    $form['token'] = [
      '#type' => 'textfield',
      '#title' => t('Web Token'),
      '#default_value' => $translator->getSetting('token'),
      '#element_validate' => ['tmgmt_acclaro_plugin_settings_form_validate'],
      '#description' => t('Please enter your Web Token or visit <a href="@url">My Acclaro Portal</a> to get one.', ['@url' => 'https://my.acclaro.com/portal/apireference.php']),
    ];
    $form['use_sandbox'] = [
      '#type' => 'checkbox',
      '#title' => t('Use the sandbox'),
      '#default_value' => $translator->getSetting('use_sandbox'),
      '#description' => t('Check to use the testing environment.'),
    ];

    return parent::pluginSettingsForm($form, $form_state, $translator, $busy);
  }

  /**
   * {@inheritdoc}
   */
  public function checkoutInfo(TMGMTJob $job) {
    $form = [];

    if ($job->isActive()) {
      $form['actions']['pull'] = [
        '#type' => 'submit',
        '#value' => t('Fetch translations'),
        '#submit' => [[$this, 'submitFetchTranslations']],
        '#weight' => -10,
      ];

      // Display simulate operations in case translator uses sandbox API key.
      if ($job->getTranslator()->getSetting('use_sandbox') && !empty($job->getRemoteMappings())) {
        $form['actions']['simulate_complete'] = [
          '#type' => 'submit',
          '#value' => t('Simulate complete'),
          '#submit' => [[$this, 'submitSimulateOrderComplete']],
        ];
      }
    }

    return $form;
  }

  /**
   * Submit callback to fetch translations from Acclaro.
   */
  public function submitFetchTranslations(array $form, $form_state) {
    /** @var \TMGMTJob $job */
    $job = $form_state['tmgmt_job'];

    /** @var \TMGMTAcclaroTranslatorPluginController $controller */
    $controller = $job->getTranslatorController();
    $controller->fetchTranslations($job);
  }

  /**
   * Submit callback to simulate completed orders from Acclaro.
   */
  public function submitSimulateOrderComplete(array $form, $form_state) {
    /** @var \TMGMTJob $job */
    $job = $form_state['tmgmt_job'];

    /** @var \TMGMTAcclaroTranslatorPluginController $controller */
    $controller = $job->getTranslatorController();
    $controller->simulateCompleteOrder($job);
  }

  /**
   * {@inheritdoc}
   */
  public function checkoutSettingsForm($form, &$form_state, TMGMTJob $job) {
    $settings['name'] = [
      '#type' => 'textfield',
      '#title' => t('Name'),
      '#default_value' => $job->getSetting('name'),
      '#description' => t('Set the name for the Acclaro order. By default, a job label will be used.'),
    ];
    $settings['comment'] = [
      '#type' => 'textfield',
      '#title' => t('Comment'),
      '#default_value' => $job->getSetting('comment'),
      '#description' => t('Set the comment for the Acclaro order.'),
    ];
    $duedate = $job->getSetting('duedate') ?: strtotime('+1 weekday');
    $settings['duedate'] = [
      '#type' => 'date',
      '#title' => t('Due Date'),
      '#default_value' => [
        'day' => isset($duedate['day']) ? $duedate['day'] : format_date($duedate, 'custom', 'd'),
        'month' => isset($duedate['month']) ? $duedate['month'] : format_date($duedate, 'custom', 'n'),
        'year' => isset($duedate['year']) ? $duedate['year'] : format_date($duedate, 'custom', 'Y'),
      ],
      '#description' => t('The deadline for providing a translation.'),
    ];

    return $settings;
  }

}
